[gnome-devel-docs] tutorials <javascript>: Changed Gtk.Dialog example to use stock OK button



commit c1cfb372a363ffbf80a1c517751446efd1c992f5
Author: Taryn Fox <jewelfox fursona net>
Date:   Fri Jun 1 23:50:16 2012 -0400

    tutorials <javascript>: Changed Gtk.Dialog example to use stock OK button

 platform-demos/C/samples/dialog.js |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/platform-demos/C/samples/dialog.js b/platform-demos/C/samples/dialog.js
index fdff8b6..83bd381 100644
--- a/platform-demos/C/samples/dialog.js
+++ b/platform-demos/C/samples/dialog.js
@@ -63,9 +63,9 @@ const DialogExample = new Lang.Class ({
         this._message = new Gtk.Label ({label: "This demonstrates a dialog with a label"});
         this._contentArea.add (this._message);
 
         // Create the dialog's action area, which contains a button
         this._actionArea = this._dialog.get_action_area();
-        this._OKButton = new Gtk.Button ({label: "OK"});
+        this._OKButton = new Gtk.Button.new_from_stock (Gtk.STOCK_OK);
         this._actionArea.add (this._OKButton);
 
         // Connect the button to the function that handles what it does
@@ -63,9 +63,9 @@ const DialogExample = new Lang.Class ({
         this._contentArea.add (this._message);
 
-        // Create the dialog's action area, which contains a button
+        // Create the dialog's action area, which contains a stock OK button
         this._actionArea = this._dialog.get_action_area();



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]